==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/ja.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "プライバシー",
    "-" : "-",
    "Add external admin" : "外部管理者を追加",
    "Your files are not protected by encryption." : "ファイルは暗号化されていません。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "あなたのファイルは {linkopen}サーバサイド暗号化↗{linkclose} で暗号化されています。",
    "This server is protected with full-disk-encryption." : "このサーバーはフルディスク暗号化で保護されています。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "あなたのファイルは {linkopen}サーバサイド暗号化↗{linkclose} で暗号化されています。さらに、このサーバーはフルディスク暗号化で保護されています。",
    "This server is using full-disk-encryption." : "このサーバーはフルディスク暗号化を使用しています。",
    "Your data is located in: " : "あなたのデータは以下に格納:",
    "The admin hasn't selected the location of the server yet." : "管理者はまだサーバーの場所を選択していません。",
    "Please select a country" : "国を選択してください",
    "You don't have any shares with individual users." : "個別のユーザとの共有はありません",
    "Somaliland" : "ソマリランド共和国",
    "United Arab Emirates" : "アラブ首長国連邦",
    "Afghanistan" : "アフガニスタン",
    "Albania" : "アルバニア",
    "Armenia" : "アルメニア",
    "Angola" : "アンゴラ",
    "Argentina" : "アルゼンチン",
    "Austria" : "オーストリア",
    "Australia" : "オーストラリア",
    "Azerbaijan" : "アゼルバイジャン",
    "Bosnia and Herzegowina" : "ボスニア・ヘルツェゴビナ",
    "Bangladesh" : "バングラデシュ",
    "Belgium" : "ベルギー",
    "Burkina Faso" : "ブルキナファソ",
    "Bulgaria" : "ブルガリア",
    "Burundi" : "ブルンジ共和国",
    "Benin" : "ベナン",
    "Brunei" : "ブルネイ",
    "Bolivia" : "ボリビア",
    "Brazil" : "ブラジル",
    "Bahamas" : "バハマ",
    "Bhutan" : "ブータン",
    "Botswana" : "ボツワナ",
    "Belarus" : "ベラルーシ",
    "Belize" : "ベリーズ",
    "Canada" : "カナダ",
    "Democratic Republic of the Congo" : "コンゴ民主共和国",
    "Central African Republic" : "中央アフリカ共和国",
    "Congo" : "コンゴ共和国",
    "Switzerland" : "スイス",
    "Cote d'Ivoire" : "コートジボワール",
    "Chile" : "チリ",
    "Cameroon" : "カメルーン",
    "China" : "中華人民共和国",
    "Colombia" : "コロンビア共和国",
    "Costa Rica" : "コスタリカ",
    "Cuba" : "キューバ",
    "Cyprus" : "キプロス共和国",
    "Czech" : "チェコ共和国",
    "Germany" : "ドイツ",
    "Djibouti" : "ジブチ",
    "Denmark" : "デンマーク",
    "Dominican Republic" : "ドミニカ共和国",
    "Algeria" : "アルジェリア民主人民共和国",
    "Ecuador" : "エクアドル",
    "Estonia" : "エストニア",
    "Egypt" : "エジプト",
    "West Sahara" : "西サハラ",
    "Eritrea" : "エリトリア",
    "Spain" : "スペイン",
    "Ethiopia" : "エチオピア",
    "Finland" : "フィンランド",
    "Fiji" : "フィジー",
    "Falkland Islands" : "フォークランド諸島",
    "France" : "フランス",
    "Gabon" : "ガボン",
    "United Kingdom" : "イギリス",
    "Georgia" : "ジョージア",
    "Ghana" : "ガーナ",
    "Greenland" : "グリーンランド",
    "Gambia" : "ガンビア",
    "Guinea" : "ギニア共和国",
    "Equatorial Guinea" : "赤道ギニア共和国",
    "Greece" : "ギリシャ",
    "Guatemala" : "グアテマラ",
    "Guinea-Bissau" : "ギニアビサウ共和国",
    "Guyana" : "ガイアナ",
    "Honduras" : "ホンジュラス",
    "Croatia" : "クロアチア",
    "Haiti" : "ハイチ",
    "Hungary" : "ハンガリー",
    "Indonesia" : "インドネシア",
    "Ireland" : "アイルランド",
    "Israel" : "イスラエル",
    "India" : "インド",
    "Iraq" : "イラク",
    "Iran" : "イラン",
    "Iceland" : "アイスランド",
    "Italy" : "イタリア",
    "Jamaica" : "ジャマイカ",
    "Jordan" : "ヨルダン・ハシミテ王国",
    "Japan" : "日本",
    "Kenya" : "ケニア",
    "Kyrgyzstan" : "キルギス",
    "Cambodia" : "カンボジア",
    "North Korea" : "朝鮮民主主義人民共和国",
    "South Korea" : "大韓民国",
    "Kuwait" : "クウェート",
    "Kazakhstan" : "カザフスタン",
    "Laos" : "ラオス",
    "Lebanon" : "レバノン",
    "Sri Lanka" : "スリランカ",
    "Liberia" : "リベリア",
    "Lesotho" : "レソト",
    "Lithuania" : "リトアニア",
    "Luxembourg" : "ルクセンブルク",
    "Latvia" : "ラトビア",
    "Libya" : "リビア",
    "Morocco" : "モロッコ",
    "Moldova" : "モルドバ",
    "Montenegro" : "モンテネグロ",
    "Madagascar" : "マダガスカル",
    "Macedonia" : "北マケドニア共和国",
    "Mali" : "マリ",
    "Myanmar" : "ミャンマー",
    "Mongolia" : "モンゴル",
    "Mauritania" : "モーリタニア",
    "Malawi" : "マラウイ共和国",
    "Mexico" : "メキシコ",
    "Malaysia" : "マレーシア",
    "Mozambique" : "モザンビーク",
    "Namibia" : "ナミビア",
    "New Caledonia" : "ニューカレドニア",
    "Niger" : "ニジェール",
    "Nigeria" : "ナイジェリア",
    "Nicaragua" : "ニカラグア",
    "Netherlands" : "オランダ",
    "Norway" : "ノルウェー",
    "Nepal" : "ネパール",
    "New Zealand" : "ニュージーランド",
    "Oman" : "オマーン",
    "Panama" : "パナマ",
    "Peru" : "ペルー",
    "Papua New Guinea" : "パプアニューギニア",
    "Philippines" : "フィリピン",
    "Pakistan" : "パキスタン",
    "Poland" : "ポーランド",
    "Puerto Rico" : "プエルトリコ",
    "Portugal" : "ポルトガル",
    "Paraguay" : "パラグアイ",
    "Qatar" : "カタール",
    "Romania" : "ルーマニア",
    "Serbia" : "セルビア",
    "Russia" : "ロシア",
    "Rwanda" : "ルワンダ",
    "Saudi Arabia" : "サウジアラビア",
    "Solomon Islands" : "ソロモン諸島",
    "Sudan" : "スーダン",
    "Sweden" : "スウェーデン",
    "Singapore" : "シンガポール",
    "Slovenia" : "スロベニア",
    "Slovakia" : "スロバキア",
    "Sierra Leone" : "シエラレオネ",
    "Senegal" : "セネガル",
    "Somalia" : "ソマリア",
    "Suriname" : "スリナム",
    "South Sudan" : "南スーダン",
    "El Salvador" : "エルサルバドル",
    "Syria" : "シリア",
    "Swaziland" : "スワジランド",
    "Chad" : "チャド",
    "Fr. S. Antarctic Lands" : "フランスの南方・南極地域",
    "Togo" : "トーゴ",
    "Thailand" : "タイ",
    "Tajikistan" : "タジキスタン",
    "Timor-Leste" : "東ティモール",
    "Turkmenistan" : "トルクメニスタン",
    "Tunisia" : "チュニジア",
    "Turkey" : "トルコ",
    "Trinidad and Tobago" : "トリニダード・トバゴ",
    "Taiwan" : "台湾",
    "Tanzania" : "タンザニア",
    "Ukraine" : "ウクライナ",
    "Uganda" : "ウガンダ",
    "United States" : "アメリカ",
    "Uruguay" : "ウルグアイ",
    "Uzbekistan" : "ウズベキスタン",
    "Venezuela" : "ベネズエラ",
    "Vietnam" : "ベトナム",
    "Vanuatu" : "バヌアツ",
    "Yemen" : "イエメン",
    "South Africa" : "南アフリカ",
    "Zambia" : "ザンビア",
    "Zimbabwe" : "ジンバブエ",
    "Your Nextcloud account" : "あなたのNextcloudアカウント",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "あなたのデータにはあなたに関する情報が含まれており、簡単に悪用される可能性があります。 Nextcloudでは、あなたがあなたのデータで何が起こるかを決める権利があると信じています。 Nextcloudはユーザーデータマニフェストで定義されているようにあなたの権利を保護します！",
    "User Data Manifesto 2.0" : "ユーザデータマニフェスト2.0",
    "Defining basic rights for people to control their own data in the internet age" : "インターネット時代に人々が自分のデータを管理するための基本的権利を定義する",
    "Control" : "コントロール",
    "over user data access" : "ユーザーデータアクセス経由",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "ユーザーによって明示的かつ意図的にアップロードされたデータは、ユーザーの最終的な管理下にあるべきです。ユーザーは、自分のデータへの直接アクセスを誰に許可するのか、およびどのアクセス権とライセンスでアクセスを許可するのかを決定できる必要があります。",
    "Knowledge" : "知見",
    "of how the data is stored" : "データの格納方法",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "データが特定のサービスプロバイダにアップロードされるとき、ユーザはその特定のサービスプロバイダがデータをどのくらいの期間、どこに保存するのか、サービスプロバイダが運営している地域、そしてどの法律が適用されるかについて知らされるべきです。",
    "Freedom" : "自由",
    "to choose a platform" : "プラットフォームを選択する",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "ユーザーはベンダーのロックインを経験することなく、いつでも自分のデータを抽出することができるはずです。これを保証するためにオープンスタンダードなフォーマットとプロトコルが必要です。",
    "Learn more ↗" : "もっと詳しく知る",
    "Where is your data?" : "あなたのデータはどこにありますか？",
    "Who has access to your data?" : "誰があなたのデータにアクセスできますか？",
    "Administrators" : "管理者",
    "People you shared with" : "あなたが共有した人",
    "Privacy policy" : "プライバシーポリシー",
    "Read the privacy policy." : "プライバシーポリシーを読みます。",
    "Encryption" : "暗号化"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/ja.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "プライバシー",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "プライバシーセンターでは、あなたのデータがどこに保存され、誰がそれにアクセスできるか、あなたがどういうデータを共有しているのか、それとも管理者からであるのかのを示します。",
    "Add external admin" : "外部管理者を追加",
    "Your files are not protected by encryption." : "ファイルは暗号化されていません。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "あなたのファイルは {linkopen}サーバサイド暗号化↗{linkclose} で暗号化されています。",
    "This server is protected with full-disk-encryption." : "このサーバーはフルディスク暗号化で保護されています。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "あなたのファイルは {linkopen}サーバサイド暗号化↗{linkclose} で暗号化されています。さらに、このサーバーはフルディスク暗号化で保護されています。",
    "This server is using full-disk-encryption." : "このサーバーはフルディスク暗号化を使用しています。",
    "Your data is located in: " : "あなたのデータは以下に格納:",
    "The admin hasn't selected the location of the server yet." : "管理者はまだサーバーの場所を選択していません。",
    "Please select a country" : "国を選択してください",
    "You don't have any shares with individual users." : "個別のユーザとの共有はありません",
    "Somaliland" : "ソマリランド共和国",
    "United Arab Emirates" : "アラブ首長国連邦",
    "Afghanistan" : "アフガニスタン",
    "Albania" : "アルバニア",
    "Armenia" : "アルメニア",
    "Angola" : "アンゴラ",
    "Argentina" : "アルゼンチン",
    "Austria" : "オーストリア",
    "Australia" : "オーストラリア",
    "Azerbaijan" : "アゼルバイジャン",
    "Bosnia and Herzegowina" : "ボスニア・ヘルツェゴビナ",
    "Bangladesh" : "バングラデシュ",
    "Belgium" : "ベルギー",
    "Burkina Faso" : "ブルキナファソ",
    "Bulgaria" : "ブルガリア",
    "Burundi" : "ブルンジ共和国",
    "Benin" : "ベナン",
    "Brunei" : "ブルネイ",
    "Bolivia" : "ボリビア",
    "Brazil" : "ブラジル",
    "Bahamas" : "バハマ",
    "Bhutan" : "ブータン",
    "Botswana" : "ボツワナ",
    "Belarus" : "ベラルーシ",
    "Belize" : "ベリーズ",
    "Canada" : "カナダ",
    "Democratic Republic of the Congo" : "コンゴ民主共和国",
    "Central African Republic" : "中央アフリカ共和国",
    "Congo" : "コンゴ共和国",
    "Switzerland" : "スイス",
    "Cote d'Ivoire" : "コートジボワール",
    "Chile" : "チリ",
    "Cameroon" : "カメルーン",
    "China" : "中華人民共和国",
    "Colombia" : "コロンビア共和国",
    "Costa Rica" : "コスタリカ",
    "Cuba" : "キューバ",
    "Cyprus" : "キプロス共和国",
    "Czech" : "チェコ共和国",
    "Germany" : "ドイツ",
    "Djibouti" : "ジブチ",
    "Denmark" : "デンマーク",
    "Dominican Republic" : "ドミニカ共和国",
    "Algeria" : "アルジェリア民主人民共和国",
    "Ecuador" : "エクアドル",
    "Estonia" : "エストニア",
    "Egypt" : "エジプト",
    "West Sahara" : "西サハラ",
    "Eritrea" : "エリトリア",
    "Spain" : "スペイン",
    "Ethiopia" : "エチオピア",
    "Finland" : "フィンランド",
    "Fiji" : "フィジー",
    "Falkland Islands" : "フォークランド諸島",
    "France" : "フランス",
    "Gabon" : "ガボン",
    "United Kingdom" : "イギリス",
    "Georgia" : "ジョージア",
    "Ghana" : "ガーナ",
    "Greenland" : "グリーンランド",
    "Gambia" : "ガンビア",
    "Guinea" : "ギニア共和国",
    "Equatorial Guinea" : "赤道ギニア共和国",
    "Greece" : "ギリシャ",
    "Guatemala" : "グアテマラ",
    "Guinea-Bissau" : "ギニアビサウ共和国",
    "Guyana" : "ガイアナ",
    "Honduras" : "ホンジュラス",
    "Croatia" : "クロアチア",
    "Haiti" : "ハイチ",
    "Hungary" : "ハンガリー",
    "Indonesia" : "インドネシア",
    "Ireland" : "アイルランド",
    "Israel" : "イスラエル",
    "India" : "インド",
    "Iraq" : "イラク",
    "Iran" : "イラン",
    "Iceland" : "アイスランド",
    "Italy" : "イタリア",
    "Jamaica" : "ジャマイカ",
    "Jordan" : "ヨルダン・ハシミテ王国",
    "Japan" : "日本",
    "Kenya" : "ケニア",
    "Kyrgyzstan" : "キルギス",
    "Cambodia" : "カンボジア",
    "North Korea" : "朝鮮民主主義人民共和国",
    "South Korea" : "大韓民国",
    "Kuwait" : "クウェート",
    "Kazakhstan" : "カザフスタン",
    "Laos" : "ラオス",
    "Lebanon" : "レバノン",
    "Sri Lanka" : "スリランカ",
    "Liberia" : "リベリア",
    "Lesotho" : "レソト",
    "Lithuania" : "リトアニア",
    "Luxembourg" : "ルクセンブルク",
    "Latvia" : "ラトビア",
    "Libya" : "リビア",
    "Morocco" : "モロッコ",
    "Moldova" : "モルドバ",
    "Montenegro" : "モンテネグロ",
    "Madagascar" : "マダガスカル",
    "Macedonia" : "北マケドニア共和国",
    "Mali" : "マリ",
    "Myanmar" : "ミャンマー",
    "Mongolia" : "モンゴル",
    "Mauritania" : "モーリタニア",
    "Malawi" : "マラウイ共和国",
    "Mexico" : "メキシコ",
    "Malaysia" : "マレーシア",
    "Mozambique" : "モザンビーク",
    "Namibia" : "ナミビア",
    "New Caledonia" : "ニューカレドニア",
    "Niger" : "ニジェール",
    "Nigeria" : "ナイジェリア",
    "Nicaragua" : "ニカラグア",
    "Netherlands" : "オランダ",
    "Norway" : "ノルウェー",
    "Nepal" : "ネパール",
    "New Zealand" : "ニュージーランド",
    "Oman" : "オマーン",
    "Panama" : "パナマ",
    "Peru" : "ペルー",
    "Papua New Guinea" : "パプアニューギニア",
    "Philippines" : "フィリピン",
    "Pakistan" : "パキスタン",
    "Poland" : "ポーランド",
    "Puerto Rico" : "プエルトリコ",
    "Portugal" : "ポルトガル",
    "Paraguay" : "パラグアイ",
    "Qatar" : "カタール",
    "Romania" : "ルーマニア",
    "Serbia" : "セルビア",
    "Russia" : "ロシア",
    "Rwanda" : "ルワンダ",
    "Saudi Arabia" : "サウジアラビア",
    "Solomon Islands" : "ソロモン諸島",
    "Sudan" : "スーダン",
    "Sweden" : "スウェーデン",
    "Singapore" : "シンガポール",
    "Slovenia" : "スロベニア",
    "Slovakia" : "スロバキア",
    "Sierra Leone" : "シエラレオネ",
    "Senegal" : "セネガル",
    "Somalia" : "ソマリア",
    "Suriname" : "スリナム",
    "South Sudan" : "南スーダン",
    "El Salvador" : "エルサルバドル",
    "Syria" : "シリア",
    "Swaziland" : "スワジランド",
    "Chad" : "チャド",
    "Fr. S. Antarctic Lands" : "フランスの南方・南極地域",
    "Togo" : "トーゴ",
    "Thailand" : "タイ",
    "Tajikistan" : "タジキスタン",
    "Timor-Leste" : "東ティモール",
    "Turkmenistan" : "トルクメニスタン",
    "Tunisia" : "チュニジア",
    "Turkey" : "トルコ",
    "Trinidad and Tobago" : "トリニダード・トバゴ",
    "Taiwan" : "台湾",
    "Tanzania" : "タンザニア",
    "Ukraine" : "ウクライナ",
    "Uganda" : "ウガンダ",
    "United States" : "アメリカ",
    "Uruguay" : "ウルグアイ",
    "Uzbekistan" : "ウズベキスタン",
    "Venezuela" : "ベネズエラ",
    "Vietnam" : "ベトナム",
    "Vanuatu" : "バヌアツ",
    "Yemen" : "イエメン",
    "South Africa" : "南アフリカ",
    "Zambia" : "ザンビア",
    "Zimbabwe" : "ジンバブエ",
    "Your Nextcloud account" : "あなたのNextcloudアカウント",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "あなたのデータにはあなたに関する情報が含まれており、簡単に悪用される可能性があります。 Nextcloudでは、あなたがあなたのデータで何が起こるかを決める権利があると信じています。 Nextcloudはユーザーデータマニフェストで定義されているようにあなたの権利を保護します！",
    "User Data Manifesto 2.0" : "ユーザデータマニフェスト2.0",
    "Defining basic rights for people to control their own data in the internet age" : "インターネット時代に人々が自分のデータを管理するための基本的権利を定義する",
    "Control" : "コントロール",
    "over user data access" : "ユーザーデータアクセス経由",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "ユーザーによって明示的かつ意図的にアップロードされたデータは、ユーザーの最終的な管理下にあるべきです。ユーザーは、自分のデータへの直接アクセスを誰に許可するのか、およびどのアクセス権とライセンスでアクセスを許可するのかを決定できる必要があります。",
    "Knowledge" : "知見",
    "of how the data is stored" : "データの格納方法",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "データが特定のサービスプロバイダにアップロードされるとき、ユーザはその特定のサービスプロバイダがデータをどのくらいの期間、どこに保存するのか、サービスプロバイダが運営している地域、そしてどの法律が適用されるかについて知らされるべきです。",
    "Freedom" : "自由",
    "to choose a platform" : "プラットフォームを選択する",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "ユーザーはベンダーのロックインを経験することなく、いつでも自分のデータを抽出することができるはずです。これを保証するためにオープンスタンダードなフォーマットとプロトコルが必要です。",
    "Learn more ↗" : "もっと詳しく知る",
    "Where is your data?" : "あなたのデータはどこにありますか？",
    "Who has access to your data?" : "誰があなたのデータにアクセスできますか？",
    "Administrators" : "管理者",
    "People you shared with" : "あなたが共有した人",
    "Privacy policy" : "プライバシーポリシー",
    "Read the privacy policy." : "プライバシーポリシーを読みます。",
    "Encryption" : "暗号化"
},
"nplurals=1; plural=0;");
